pub async fn handle_udp_send<C: QuicConnection>(
send: C::SendStream,
udp_recv: AnyUdpRecv,
conn: SQConn<C>,
over_stream: bool,
) -> Result<(), SError>Expand description
Handle udp packets send It watches the udp socket and sends the packets to the quic connection. This function is symetrical for both clients and servers.